<?php

namespace Drupal\moon_phases\Cache;

use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Cache\Context\CacheContextInterface;
use Drupal\Core\Datetime\DateFormatterInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines the MoonPhasesDateCacheContext service, for "moon_phases" caching.
 *
 * Cache context ID: 'moon_phases_date'.
 */
class MoonPhasesDateCacheContext implements CacheContextInterface, ContainerFactoryPluginInterface {

  /**
   * Returns the date.formatter service.
   *
   * @var \Drupal\Core\Datetime\DateFormatterInterface
   */
  protected DateFormatterInterface $dateFormatter;

  /**
   * Returns the datetime.time service.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected TimeInterface $timeService;

  /**
   * Constructs an MoonPhasesDateCacheContext object.
   *
   * @param \Drupal\Core\Datetime\DateFormatterInterface $date_formatter
   *   Provides an interface defining a date formatter.
   * @param \Drupal\Component\Datetime\TimeInterface $time_service
   *   Defines an interface for obtaining system time.
   */
  public function __construct(DateFormatterInterface $date_formatter, TimeInterface $time_service) {
    $this->dateFormatter = $date_formatter;
    $this->timeService = $time_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $container->get('date.formatter'),
      $container->get('datetime.time')
    );
  }

  /**
   * {@inheritdoc}
   */
  public static function getLabel() {
    return new TranslatableMarkup('Moon phase date');
  }

  /**
   * {@inheritdoc}
   */
  public function getContext() {
    $current_time = $this->timeService->getCurrentTime();
    return $this->dateFormatter->format($current_time, 'custom', 'Y-m-d');
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheableMetadata() {
    return new CacheableMetadata();
  }

}
