<?php

namespace Drupal\moon_phases\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form handler for adding moon phase settings.
 */
class MoonPhasesSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'moon_phases_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function getEditableConfigNames() {
    return ['moon_phases.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('moon_phases.settings');

    $form['show_attribution'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show attribution'),
      '#description' => $this->t('Show the attribution for the moon phase images.'),
      '#default_value' => $config->get('show_attribution') ?? FALSE,
    ];

    $form['new_moon'] = [
      '#type' => 'text_format',
      '#title' => $this->t('New Moon description'),
      '#default_value' => $config->get('new_moon')['value'] ?? '',
      '#format' => $config->get('new_moon')['format'] ?? '',
    ];

    $form['waxing_crescent'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Waxing Crescent Moon description'),
      '#default_value' => $config->get('waxing_crescent')['value'] ?? '',
      '#format' => $config->get('waxing_crescent')['format'] ?? '',
    ];

    $form['first_quarter'] = [
      '#type' => 'text_format',
      '#title' => $this->t('First Quarter Moon description'),
      '#default_value' => $config->get('first_quarter')['value'] ?? '',
      '#format' => $config->get('first_quarter')['format'] ?? '',
    ];

    $form['waxing_gibbous'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Waxing Gibbous Moon description'),
      '#default_value' => $config->get('waxing_gibbous')['value'] ?? '',
      '#format' => $config->get('waxing_gibbous')['format'] ?? '',
    ];

    $form['full_moon'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Full Moon description'),
      '#default_value' => $config->get('full_moon')['value'] ?? '',
      '#format' => $config->get('full_moon')['format'] ?? '',
    ];

    $form['waning_gibbous'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Waning Moon description'),
      '#default_value' => $config->get('waning_gibbous')['value'] ?? '',
      '#format' => $config->get('waning_gibbous')['format'] ?? '',
    ];

    $form['last_quarter'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Last Quarter Moon description'),
      '#default_value' => $config->get('last_quarter')['value'] ?? '',
      '#format' => $config->get('last_quarter')['format'] ?? '',
    ];

    $form['waning_crescent'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Waning Crescent Moon description'),
      '#default_value' => $config->get('waning_crescent')['value'] ?? '',
      '#format' => $config->get('waning_crescent')['format'] ?? '',
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('moon_phases.settings')
      ->set('show_attribution', (bool) $form_state->getValue('show_attribution'))
      ->set('new_moon', $form_state->getValue('new_moon'))
      ->set('waxing_crescent', $form_state->getValue('waxing_crescent'))
      ->set('first_quarter', $form_state->getValue('first_quarter'))
      ->set('waxing_gibbous', $form_state->getValue('waxing_gibbous'))
      ->set('full_moon', $form_state->getValue('full_moon'))
      ->set('waning_gibbous', $form_state->getValue('waning_gibbous'))
      ->set('last_quarter', $form_state->getValue('last_quarter'))
      ->set('waning_crescent', $form_state->getValue('waning_crescent'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
